public inbox for gentoo-commits@lists.gentoo.org
 help / color / mirror / Atom feed
* [gentoo-commits] gentoo-x86 commit in app-editors/qemacs/files: qemacs-0.4.0_pre20080605-make_backup.patch qemacs-0.4.0_pre20080605-qemacs-datadir.patch qemacs-0.4.0_pre20080605-Makefile-gentoo.patch
@ 2009-03-07 20:33 Christian Faulhammer (fauli)
  0 siblings, 0 replies; only message in thread
From: Christian Faulhammer (fauli) @ 2009-03-07 20:33 UTC (permalink / raw
  To: gentoo-commits

fauli       09/03/07 20:33:45

  Added:                qemacs-0.4.0_pre20080605-make_backup.patch
                        qemacs-0.4.0_pre20080605-qemacs-datadir.patch
                        qemacs-0.4.0_pre20080605-Makefile-gentoo.patch
  Log:
  version bump with snapshot from upstream CVS
  (Portage version: 2.1.6.7/cvs/Linux i686)

Revision  Changes    Path
1.1                  app-editors/qemacs/files/qemacs-0.4.0_pre20080605-make_backup.patch

file : http://sources.gentoo.org/viewcvs.py/gentoo-x86/app-editors/qemacs/files/qemacs-0.4.0_pre20080605-make_backup.patch?rev=1.1&view=markup
plain: http://sources.gentoo.org/viewcvs.py/gentoo-x86/app-editors/qemacs/files/qemacs-0.4.0_pre20080605-make_backup.patch?rev=1.1&content-type=text/plain

Index: qemacs-0.4.0_pre20080605-make_backup.patch
===================================================================
--- buffer.c.orig	2009-03-07 21:14:02.000000000 +0100
+++ buffer.c	2009-03-07 21:15:40.000000000 +0100
@@ -1657,12 +1657,14 @@
     if (stat(filename, &st) == 0)
         mode = st.st_mode & 0777;
 
-    /* backup old file if present */
-    if (strlen(filename) < MAX_FILENAME_SIZE - 1) {
+    /* backup old file if present and make-backup-files is on */
+    if(mbf == 1) {
+      if (strlen(filename) < MAX_FILENAME_SIZE - 1) {
         if (snprintf(buf1, sizeof(buf1), "%s~", filename) < ssizeof(buf1)) {
             // should check error code
             rename(filename, buf1);
         }
+      }
     }
 
     /* CG: should pass mode to buffer_save */
--- qe.c.orig	2009-03-07 21:14:09.000000000 +0100
+++ qe.c	2009-03-07 21:17:01.000000000 +0100
@@ -71,6 +71,7 @@
 static int screen_height = 0;
 static int no_init_file;
 static const char *user_option;
+mbf = 1;
 
 /* mode handling */
 
@@ -5316,6 +5317,14 @@
     do_refresh(qs->first_window);
 }
 
+static void make_backup_files(EditState *s) {
+	if(mbf == 1) {
+		mbf = 0;
+	} else {
+		mbf = 1;
+	}
+}
+
 /* compute default path for find/save buffer */
 static void get_default_path(EditState *s, char *buf, int buf_size)
 {
--- qeconfig.h.orig	2009-03-07 21:14:19.000000000 +0100
+++ qeconfig.h	2009-03-07 21:17:37.000000000 +0100
@@ -192,6 +192,7 @@
           "downcase-region", do_changecase_region, ESi, -1, "*v")
     CMD3( KEY_CTRLX(KEY_CTRL('u')), KEY_NONE,
           "upcase-region", do_changecase_region, ESi, 1, "*v")
+    CMD0( KEY_NONE, KEY_NONE, "make-backup-files", make_backup_files)
 
     /*---------------- Command handling ----------------*/
 
--- qe.h.orig	2009-03-07 21:14:26.000000000 +0100
+++ qe.h	2009-03-07 21:17:53.000000000 +0100
@@ -1765,6 +1765,7 @@
 /* image.c */
 void fill_border(EditState *s, int x, int y, int w, int h, int color);
 int qe_bitmap_format_to_pix_fmt(int format);
+int mbf;
 
 /* shell.c */
 EditBuffer *new_shell_buffer(EditBuffer *b0, const char *name,



1.1                  app-editors/qemacs/files/qemacs-0.4.0_pre20080605-qemacs-datadir.patch

file : http://sources.gentoo.org/viewcvs.py/gentoo-x86/app-editors/qemacs/files/qemacs-0.4.0_pre20080605-qemacs-datadir.patch?rev=1.1&view=markup
plain: http://sources.gentoo.org/viewcvs.py/gentoo-x86/app-editors/qemacs/files/qemacs-0.4.0_pre20080605-qemacs-datadir.patch?rev=1.1&content-type=text/plain

--- qe-doc.texi.orig	2009-03-07 21:00:56.000000000 +0100
+++ qe-doc.texi	2009-03-07 21:08:49.000000000 +0100
@@ -274,11 +274,11 @@
 @section Resource path
 
 All resources and configuration files are looked in the following paths:
-@file{/usr/share/qe:/usr/local/share/qe:/usr/lib/qe:/usr/local/lib/qe:~/.qe}
+@file{/usr/share/qemacs:/usr/local/share/qemacs:/usr/lib/qemacs:/usr/local/lib/qemacs:~/.qemacs}
 
 @section Configuration file
 
-QEmacs tries to load a configuration file in @file{~/.qe/config}. Each
+QEmacs tries to load a configuration file in @file{~/.qemacs/config}. Each
 line of the configuration file is a QEmacs command with a C like syntax
 ('-' in command name can be replaced by '_').
 
--- qe-doc.html.orig	2009-03-07 21:01:02.000000000 +0100
+++ qe-doc.html	2009-03-07 21:08:49.000000000 +0100
@@ -619,7 +619,7 @@
 <h2 class="section"> 4.1 Resource path </h2>
 
 <p>All resources and configuration files are looked in the following paths:
-&lsquo;<tt>/usr/share/qe:/usr/local/share/qe:/usr/lib/qe:/usr/local/lib/qe:~/.qe</tt>&rsquo;
+&lsquo;<tt>/usr/share/qemacs:/usr/local/share/qemacs:/usr/lib/qemacs:/usr/local/lib/qemacs:~/.qemacs</tt>&rsquo;
 </p>
 <hr size="6">
 <a name="SEC19"></a>
@@ -641,7 +641,7 @@
 </tr></table>
 <h2 class="section"> 4.2 Configuration file </h2>
 
-<p>QEmacs tries to load a configuration file in &lsquo;<tt>~/.qe/config</tt>&rsquo;. Each
+<p>QEmacs tries to load a configuration file in &lsquo;<tt>~/.qemacs/config</tt>&rsquo;. Each
 line of the configuration file is a QEmacs command with a C like syntax
 ('-' in command name can be replaced by '_').
 </p>
--- config.eg.orig	2009-03-07 21:00:21.000000000 +0100
+++ config.eg	2009-03-07 21:08:49.000000000 +0100
@@ -1,6 +1,6 @@
 // Sample qemacs config file 
 //
-// copy it in ~/.qe/config
+// copy it in ~/.qemacs/config
 //
 // You can call any Qemacs command with a C like syntax.
 //



1.1                  app-editors/qemacs/files/qemacs-0.4.0_pre20080605-Makefile-gentoo.patch

file : http://sources.gentoo.org/viewcvs.py/gentoo-x86/app-editors/qemacs/files/qemacs-0.4.0_pre20080605-Makefile-gentoo.patch?rev=1.1&view=markup
plain: http://sources.gentoo.org/viewcvs.py/gentoo-x86/app-editors/qemacs/files/qemacs-0.4.0_pre20080605-Makefile-gentoo.patch?rev=1.1&content-type=text/plain

Index: qemacs-0.4.0_pre20080605-Makefile-gentoo.patch
===================================================================
--- Makefile.orig	2009-03-07 21:27:48.000000000 +0100
+++ Makefile	2009-03-07 21:28:43.000000000 +0100
@@ -19,32 +19,6 @@
 
 include config.mak
 
-ifeq ($(CC),gcc)
-  CFLAGS   := -Wall -g -O2 -funsigned-char
-  # do not warn about zero-length formats.
-  CFLAGS   += -Wno-format-zero-length
-  LDFLAGS  := -g
-endif
-
-#include local compiler configuration file
--include cflags.mk
-
-ifdef TARGET_GPROF
-  CFLAGS   += -p
-  LDFLAGS  += -p
-endif
-
-TLDFLAGS := $(LDFLAGS)
-
-ifdef TARGET_ARCH_X86
-  #CFLAGS+=-fomit-frame-pointer
-  ifeq ($(GCC_MAJOR),2)
-    CFLAGS+=-m386 -malign-functions=0
-  else
-    CFLAGS+=-march=i386 -falign-functions=0
-  endif
-endif
-
 DEFINES=-DHAVE_QE_CONFIG_H
 
 ########################################################
@@ -354,16 +328,16 @@
 install: $(TARGETS) qe.1
 	$(INSTALL) -m 755 -d $(DESTDIR)$(prefix)/bin
 	$(INSTALL) -m 755 -d $(DESTDIR)$(prefix)/man/man1
-	$(INSTALL) -m 755 -d $(DESTDIR)$(prefix)/share/qe
+	$(INSTALL) -m 755 -d $(DESTDIR)$(prefix)/share/qemacs
 	$(INSTALL) -m 755 -s qe$(EXE) $(DESTDIR)$(prefix)/bin/qemacs$(EXE)
-	ln -sf qemacs $(DESTDIR)$(prefix)/bin/qe$(EXE)
 ifdef CONFIG_FFMPEG
 	ln -sf qemacs$(EXE) $(DESTDIR)$(prefix)/bin/ffplay$(EXE)
 endif
-	$(INSTALL) -m 644 kmaps ligatures $(DESTDIR)$(prefix)/share/qe
-	$(INSTALL) -m 644 qe.1 $(DESTDIR)$(prefix)/man/man1
+	$(INSTALL) -m 644 kmaps ligatures $(DESTDIR)$(prefix)/share/qemacs
+	$(INSTALL) -m 644 qe.1 $(DESTDIR)$(prefix)/man/man1/qemacs.1
 ifdef CONFIG_HTML
 	$(INSTALL) -m 755 -s html2png$(EXE) $(DESTDIR)$(prefix)/bin
+	$(INSTALL) -m 755 libqhtml/csstoqe $(DESTDIR)$(prefix)/bin/csstoqe
 endif
 
 uninstall:






^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2009-03-07 20:33 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2009-03-07 20:33 [gentoo-commits] gentoo-x86 commit in app-editors/qemacs/files: qemacs-0.4.0_pre20080605-make_backup.patch qemacs-0.4.0_pre20080605-qemacs-datadir.patch qemacs-0.4.0_pre20080605-Makefile-gentoo.patch Christian Faulhammer (fauli)

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
Index: qemacs-0.4.0_pre20080605-qemacs-datadir.patch
===================================================================
--- qe.c.orig	2009-03-07 21:00:39.000000000 +0100
+++ qe.c	2009-03-07 21:10:50.000000000 +0100
@@ -7505,15 +7505,15 @@
     /* compute resources path */
     qs->res_path[0] = '\0';
 
     /* put source directory first if qe invoked as ./qe */
     // should use actual directory
-    if (stristart(qs->argv[0], "./qe", NULL)) {
+    if (stristart(qs->argv[0], "./qemacs", NULL)) {
         pstrcat(qs->res_path, sizeof(qs->res_path), ".:");
     }
 
     /* put user directory before standard list */
     if (user) {
         /* use ~USER/.qe instead of ~/.qe */
         /* CG: should get user homedir */
         snprintf(path, sizeof(path), "/home/%s", user);
         home_path = path;
@@ -7522,14 +7522,14 @@
     }
     if (home_path) {
         pstrcat(qs->res_path, sizeof(qs->res_path), home_path);
-        pstrcat(qs->res_path, sizeof(qs->res_path), "/.qe:");
+        pstrcat(qs->res_path, sizeof(qs->res_path), "/.qemacs:");
     }
 
     pstrcat(qs->res_path, sizeof(qs->res_path),
-            CONFIG_QE_PREFIX "/share/qe:"
-            CONFIG_QE_PREFIX "/lib/qe:"
-            "/usr/share/qe:"
-            "/usr/lib/qe");
+            CONFIG_QE_PREFIX "/share/qemacs:"
+            CONFIG_QE_PREFIX "/lib/qemacs:"
+            "/usr/share/qemacs:"
+            "/usr/lib/qemacs");
 }
 
 void set_tty_charset(const char *name)
@@ -7545,7 +7545,7 @@
       { .int_ptr = &no_init_file }},
     { "ttycharset", "c", "CHARSET", CMD_OPT_ARG, "specify tty charset",
       { .func_arg = set_tty_charset }},
-    { "user", "u", "USER", CMD_OPT_ARG, "load ~USER/.qe/config instead of your own",
+    { "user", "u", "USER", CMD_OPT_ARG, "load ~USER/.qemacs/config instead of your own",
       { .func_arg = set_user_option }},
     { "version", "V", NULL, 0, "display version information and exit",
       { .func_noarg = show_version }},
@@ -7505,15 +7505,15 @@
     qs->res_path[0] = '\0';
 
-    /* put source directory first if qe invoked as ./qe */
+    /* put source directory first if qe invoked as ./qemacs */
     // should use actual directory
@@ -7505,15 +7505,15 @@
     /* put user directory before standard list */
     if (user) {
-        /* use ~USER/.qe instead of ~/.qe */
+        /* use ~USER/.qemacs instead of ~/.qemacs */
         /* CG: should get user homedir */
         snprintf(path, sizeof(path), "/home/%s", user);